diff --git a/backend/igny8_core/ai/ai_core.py b/backend/igny8_core/ai/ai_core.py
index 2ea810cb..589c60be 100644
--- a/backend/igny8_core/ai/ai_core.py
+++ b/backend/igny8_core/ai/ai_core.py
@@ -800,7 +800,7 @@ class AICore:
if image_url:
- cost = 0.036 * n # Runware pricing
+ cost = 0.009 * n # Runware pricing
print(f"[AI][{function_name}] Step 5: Image generated successfully")
print(f"[AI][{function_name}] Step 6: Cost: ${cost:.4f}")
print(f"[AI][{function_name}][Success] Image generation completed")
diff --git a/backend/igny8_core/modules/system/integration_views.py b/backend/igny8_core/modules/system/integration_views.py
index bdce6a69..fbcc85bf 100644
--- a/backend/igny8_core/modules/system/integration_views.py
+++ b/backend/igny8_core/modules/system/integration_views.py
@@ -335,7 +335,7 @@ class IntegrationSettingsViewSet(viewsets.ViewSet):
'success': True,
'message': '✅ Runware API connected successfully!',
'image_url': image_url,
- 'cost': '$0.0360',
+ 'cost': '$0.0090',
'provider': 'runware',
'model': 'runware:97@1',
'size': '128x128'
diff --git a/frontend/src/components/common/ValidationCard.tsx b/frontend/src/components/common/ValidationCard.tsx
index b8d6faec..4320ada8 100644
--- a/frontend/src/components/common/ValidationCard.tsx
+++ b/frontend/src/components/common/ValidationCard.tsx
@@ -239,7 +239,7 @@ export default function ValidationCard({
Cost:{' '}
- {testResult.cost || '$0.0360'}
+ {testResult.cost || '$0.0090'}
{testResult.full_response?.image_url && (
diff --git a/frontend/src/pages/Settings/Integration.tsx b/frontend/src/pages/Settings/Integration.tsx
index 1b6b023f..b5619da6 100644
--- a/frontend/src/pages/Settings/Integration.tsx
+++ b/frontend/src/pages/Settings/Integration.tsx
@@ -557,7 +557,7 @@ export default function Integration() {
},
options: [
{ value: 'openai', label: 'OpenAI - Multiple models available' },
- { value: 'runware', label: 'Runware - $0.036 per image' },
+ { value: 'runware', label: 'Runware - $0.009 per image' },
],
},
];
@@ -596,9 +596,9 @@ export default function Integration() {
});
},
options: [
- { value: 'runware:97@1', label: 'HiDream-I1 Full - $0.036 per image' },
- { value: 'runware:gen3a_turbo', label: 'Gen3a Turbo - $0.036 per image' },
- { value: 'runware:gen3a', label: 'Gen3a - $0.036 per image' },
+ { value: 'runware:97@1', label: 'HiDream-I1 Full - $0.009 per image' },
+ { value: 'runware:gen3a_turbo', label: 'Gen3a Turbo - $0.009 per image' },
+ { value: 'runware:gen3a', label: 'Gen3a - $0.009 per image' },
],
});
}
@@ -892,7 +892,7 @@ export default function Integration() {
}
title="Runware"
- description="High-quality AI image generation with Runware's models ($0.036 per image)"
+ description="High-quality AI image generation with Runware's models ($0.009 per image)"
validationStatus={validationStatuses.runware}
integrationId="runware"
modelName={
diff --git a/igny8-ai-seo-wp-plugin/ai/runware-api.php b/igny8-ai-seo-wp-plugin/ai/runware-api.php
index 77241e39..eb2fd74b 100644
--- a/igny8-ai-seo-wp-plugin/ai/runware-api.php
+++ b/igny8-ai-seo-wp-plugin/ai/runware-api.php
@@ -83,7 +83,7 @@ function igny8_runway_generate_image($prompt, $model = 'gen3a_turbo') {
igny8_log_ai_event('runway_api_success', 'success', [
'model' => $model,
'prompt_length' => strlen($prompt),
- 'cost' => 0.036, // Runware pricing
+ 'cost' => 0.009, // Runware pricing
'service' => 'runware'
]);
diff --git a/igny8-ai-seo-wp-plugin/modules/settings/integration.php b/igny8-ai-seo-wp-plugin/modules/settings/integration.php
index 03729271..aa11d0a6 100644
--- a/igny8-ai-seo-wp-plugin/modules/settings/integration.php
+++ b/igny8-ai-seo-wp-plugin/modules/settings/integration.php
@@ -109,7 +109,7 @@ ob_start();
@@ -150,7 +150,7 @@ ob_start();
diff --git a/backend/igny8_core/utils/ai_processor.py b/backend/igny8_core/utils/ai_processor.py
index d4abee3d..a8d3460f 100644
--- a/backend/igny8_core/utils/ai_processor.py
+++ b/backend/igny8_core/utils/ai_processor.py
@@ -977,8 +977,8 @@ Make sure each prompt is detailed enough for image generation, describing the vi
if image_url:
logger.info(f"[AIProcessor.generate_image] Image URL extracted: {image_url[:50]}...")
- # Calculate cost (Runware: $0.036 per image)
- cost = 0.036
+ # Calculate cost (Runware: $0.009 per image)
+ cost = 0.009
logger.info(f"[AIProcessor.generate_image] Cost calculated: ${cost:.4f}")
return {